Functions facilitating sending of Deploys to the network
Functions
- make_
deploy - Returns a
Deployand outputs it to a file or stdout if thestd-fs-iofeature is enabled. - make_
transfer - Returns a transfer
Deployand outputs it to a file or stdout if thestd-fs-iofeature is enabled. - new_
transfer - Creates new Transfer with specified data.
- put_
deploy - Creates a
Deployand sends it to the network for execution. - put_
deploy_ with_ min_ bid_ override - Creates a
Deployand sends it to the network for execution. - send_
deploy_ file - Reads a previously-saved
Deployfrom a file and sends it to the network for execution. - sign_
deploy_ file - Reads a previously-saved
Deployfrom a file, cryptographically signs it, and outputs it to a file or stdout. - speculative_
put_ deploy - Creates a
Deployand sends it to the specified node for speculative execution. - speculative_
send_ deploy_ file - Reads a previously-saved
Deployfrom a file and sends it to the specified node for speculative execution. For details of the parameters, see the module docs. - speculative_
transfer - Creates a
Deployto transfer funds between purses, and sends it to the specified node for speculative execution. - transfer
- Transfers funds between purses.
- with_
payment_ and_ session - Creates new Deploy with specified payment and session data.