speculative_put_deploy

Function speculative_put_deploy 

pub async fn speculative_put_deploy(
    maybe_rpc_id: &str,
    node_address: &str,
    verbosity_level: u64,
    deploy_params: DeployStrParams<'_>,
    session_params: SessionStrParams<'_>,
    payment_params: PaymentStrParams<'_>,
) -> Result<SuccessResponse<SpeculativeExecResult>, CliError>
Creates a Deploy and sends it to the specified node for speculative execution.

For details of the parameters, see the module docs or the docs of the individual parameter types.