speculative_send_deploy_file

Function speculative_send_deploy_file 

pub async fn speculative_send_deploy_file(
    maybe_rpc_id: &str,
    node_address: &str,
    verbosity_level: u64,
    input_path: &str,
) -> Result<SuccessResponse<SpeculativeExecResult>, CliError>
Reads a previously-saved Deploy from a file and sends it to the specified node for speculative execution. For details of the parameters, see the module docs.