speculative_transfer

Function speculative_transfer 

pub async fn speculative_transfer(
    maybe_rpc_id: &str,
    node_address: &str,
    verbosity_level: u64,
    amount: &str,
    target_account: &str,
    transfer_id: &str,
    deploy_params: DeployStrParams<'_>,
    payment_params: PaymentStrParams<'_>,
) -> Result<SuccessResponse<SpeculativeExecResult>, CliError>
Creates a Deploy to transfer funds between purses, and sends it to the specified node for speculative execution.

  • amount is a string to be parsed as a U512 specifying the amount to be transferred.
  • target_account is the AccountHash, URef or PublicKey of the account to which the funds will be transferred, formatted as a hex-encoded string. The account’s main purse will receive the funds.
  • transfer_id is a string to be parsed as a u64 representing a user-defined identifier which will be permanently associated with the transfer.

For details of other parameters, see the module docs.