pub enum CliError {
Show 16 variants
FailedToParseKey {
context: &'static str,
error: KeyFromStrError,
},
FailedToParsePublicKey {
context: String,
error: Error,
},
FailedToParseAccountHash {
context: &'static str,
error: FromStrError,
},
FailedToParseURef {
context: &'static str,
error: URefFromStrError,
},
FailedToParseInt {
context: &'static str,
error: ParseIntError,
},
FailedToParseTimeDiff {
context: &'static str,
error: DurationError,
},
FailedToParseTimestamp {
context: &'static str,
error: TimestampError,
},
FailedToParseUint {
context: &'static str,
error: UIntParseError,
},
FailedToParseDigest {
context: &'static str,
error: Error,
},
FailedToParseStateIdentifier,
ConflictingArguments {
context: &'static str,
args: Vec<String>,
},
InvalidCLValue(String),
InvalidArgument {
context: &'static str,
error: String,
},
FailedToParseJsonArgs(Error),
JsonArgs(JsonArgsError),
Core(Error),
}Expand description
Error that can be returned by the cli API.
Variants
FailedToParseKey
Failed to parse a Key from a formatted string.
Fields
error: KeyFromStrErrorThe actual error raised.
FailedToParsePublicKey
Failed to parse a PublicKey from a formatted string.
Fields
FailedToParseAccountHash
Failed to parse an AccountHash from a formatted string.
Fields
error: FromStrErrorThe actual error raised.
FailedToParseURef
Failed to parse a URef from a formatted string.
Fields
context: &'static strContextual description of where this error occurred including relevant paths, filenames, etc.
error: URefFromStrErrorThe actual error raised.
FailedToParseInt
Failed to parse an integer from a string.
Fields
context: &'static strContextual description of where this error occurred including relevant paths, filenames, etc.
error: ParseIntErrorThe actual error raised.
FailedToParseTimeDiff
Failed to parse a TimeDiff from a formatted string.
Fields
context: &'static strContextual description of where this error occurred including relevant paths, filenames, etc.
error: DurationErrorThe actual error raised.
FailedToParseTimestamp
Failed to parse a Timestamp from a formatted string.
Fields
context: &'static strContextual description of where this error occurred including relevant paths, filenames, etc.
error: TimestampErrorThe actual error raised.
FailedToParseUint
Failed to parse a U128, U256 or U512 from a string.
Fields
context: &'static strContextual description of where this error occurred including relevant paths, filenames, etc.
error: UIntParseErrorThe actual error raised.
FailedToParseDigest
Failed to parse a Digest from a string.
Fields
FailedToParseStateIdentifier
Failed to create a GlobalStateIdentifier.
ConflictingArguments
Conflicting arguments.
Fields
InvalidCLValue(String)
Invalid CLValue.
InvalidArgument
Invalid argument.
Fields
FailedToParseJsonArgs(Error)
Error while parsing the json-args from a string to JSON.
JsonArgs(JsonArgsError)
Error while building a NamedArg from parsed JSON input.
Core(Error)
Core error.