Enum JsonArgsErrorDetails

pub enum JsonArgsErrorDetails {
Show 25 variants Bytesrepr(Error), CannotParseToI32, CannotParseToI64, CannotParseToU8, CannotParseToU32, CannotParseToU64, ParseInt(ParseIntError), ParseBigint(FromDecStrErr), ParseKeyFromString(KeyFromStrError), KeyObjectHasInvalidNumberOfFields, KeyObjectHasInvalidFieldType, KeyObjectHasInvalidVariant, ParseURef(URefFromStrError), ParsePublicKey(Error), HexDecode(DecodeError), ByteArrayLengthMismatch { expected_length: u32, actual_length: u32, }, ResultObjectHasInvalidNumberOfFields, ResultObjectHasInvalidVariant, MapTypeNotValidAsObject(CLType), MapArrayHasInvalidEntryType, MapEntryObjectHasInvalidNumberOfFields, MapEntryObjectMissingKeyField, MapEntryObjectMissingValueField, TupleEntryCountMismatch { expected: usize, actual: usize, }, IncompatibleType,
}
Details of an error associated with parsing a JSON arg into a NamedArg.

Variants



Bytesrepr(Error)

bytesrepr error while constructing a CLValue.



CannotParseToI32

Cannot convert the given JSON Number to an i32.



CannotParseToI64

Cannot convert the given JSON Number to an i64.



CannotParseToU8

Cannot convert the given JSON Number to a u8.



CannotParseToU32

Cannot convert the given JSON Number to a u32.



CannotParseToU64

Cannot convert the given JSON Number to a u64.



ParseInt(ParseIntError)

Error parsing an integer from a decimal string representation.



ParseBigint(FromDecStrErr)

Error parsing a big integer from a decimal string representation.



ParseKeyFromString(KeyFromStrError)

Error parsing a Key from a formatted string representation.



KeyObjectHasInvalidNumberOfFields

JSON Object representing a Key must have the structure {"<KEY VARIANT>":"<KEY AS FORMATTED STRING>"}, but the given one does not have just one field.



KeyObjectHasInvalidFieldType

JSON Object representing a Key must have the structure {"<KEY VARIANT>":"<KEY AS FORMATTED STRING>"}, but the given one does not have a String value.



KeyObjectHasInvalidVariant

JSON Object representing a Key must have the structure {"<KEY VARIANT>":"<KEY AS FORMATTED STRING>"}, but the given one does match any valid Key variant.



ParseURef(URefFromStrError)

Error parsing a URef from a formatted string representation.



ParsePublicKey(Error)

Error parsing a PublicKey from a formatted string representation.



HexDecode(DecodeError)

Error parsing a hex string.



ByteArrayLengthMismatch

Number of hex-decoded bytes not as expected.

Fields

expected_length: u32

The expected number of bytes.

actual_length: u32

The actual number of bytes.



ResultObjectHasInvalidNumberOfFields

JSON Object representing a Result must have the structure {"Ok":<VALUE>} or {"Err":<VALUE>}, but the given one does not have just one field.



ResultObjectHasInvalidVariant

JSON Object representing a Result must have the structure {"Ok":<VALUE>} or {"Err":<VALUE>}, but the given one is neither "Ok" nor "Err".



MapTypeNotValidAsObject(CLType)

CLType::Maps can only be represented as JSON Objects if the map’s key type is a string or number.



MapArrayHasInvalidEntryType

JSON Array representing a CLType::Map must have all entries with the structure {"key":<VALUE>,"value":<VALUE>}, but the given one has an entry which is not an Object.



MapEntryObjectHasInvalidNumberOfFields

JSON Object representing a map entry must have the structure {"key":<VALUE>,"value":<VALUE>}, but the given one does not have exactly two fields.



MapEntryObjectMissingKeyField

JSON Object representing a map entry must have the structure {"key":<VALUE>,"value":<VALUE>}, but the given one does not have "key".



MapEntryObjectMissingValueField

JSON Object representing a map entry must have the structure {"key":<VALUE>,"value":<VALUE>}, but the given one does not have "value".



TupleEntryCountMismatch

Number of tuple entries not as expected.

Fields

expected: usize

The expected number of tuple entries.

actual: usize

The actual number of tuple entries.



IncompatibleType

The given CLType fundamentally cannot be constructed from the given type of JSON value.