get_validator_changes

Function get_validator_changes 

pub async fn get_validator_changes(
    maybe_rpc_id: &str,
    node_address: &str,
    verbosity_level: u64,
) -> Result<SuccessResponse<GetValidatorChangesResult>, CliError>
Retrieves the status changes of the active validators on the network.

For details of the parameters, see the module docs.