query_balance

Function query_balance 

pub async fn query_balance(
    maybe_rpc_id: &str,
    node_address: &str,
    verbosity_level: u64,
    maybe_block_id: &str,
    maybe_state_root_hash: &str,
    purse_id: &str,
) -> Result<SuccessResponse<QueryBalanceResult>, CliError>
Retrieves a purse’s balance from global state.

maybe_block_id or maybe_state_root_hash identify the global state root hash to be used for the query. If both are empty, the latest block is used.

purse_id can be a properly-formatted public key, account hash, entity address or URef.

For details of other parameters, see the module docs.