Module parse

Module parse 

This module contains structs and helpers which are used by multiple subcommands related to creating deploys.

Functions

account_identifier
account_identifier can be a formatted public key, in the form of a hex-formatted string, a pem file, or a file containing a hex formatted string, or a formatted string representing an account hash. It may not be empty.
args_from_simple_or_json
Constructs a RuntimeArgs instance from either simple or JSON representation.
entity_identifier
entity_identifier can be a formatted public key, in the form of a hex-formatted string, a pem file, or a file containing a hex formatted string, or a formatted string representing an account hash. It may not be empty.
purse_identifier
purse_id can be a formatted public key, account hash, or URef. It may not be empty.
transaction_module_bytes
Parse a transaction file into Bytes to be used in crafting a new session transaction
transfer_target
Parses transfer target from a string for use with the transaction builder
uref
Parses a URef from a formatted string for the purposes of creating transactions.