pub fn transfer_target(target_str: &str) -> Result<TransferTarget, CliError>Expand description
Parses transfer target from a string for use with the transaction builder
pub fn transfer_target(target_str: &str) -> Result<TransferTarget, CliError>Parses transfer target from a string for use with the transaction builder