pub struct DeployStrParams<'a> {
pub secret_key: &'a str,
pub timestamp: &'a str,
pub ttl: &'a str,
pub chain_name: &'a str,
pub session_account: &'a str,
pub gas_price_tolerance: &'a str,
}Expand description
Container for Deploy construction options.
Fields
secret_key: &'a strPath to secret key file if the std-fs-io feature is enabled (enabled by default), or a
PEM-encoded secret key if not.
If secret_key is empty, the new deploy will not be signed and will need to be signed (e.g.
via sign_deploy_file) at least once in order to be made valid.
timestamp: &'a strRFC3339-like formatted timestamp. e.g. 2018-02-16T00:31:37Z.
If timestamp is empty, the current time will be used. Note that timestamp is UTC, not
local.
See humantime::parse_rfc3339_weak for more information.
ttl: &'a strTime that the Deploy will remain valid for.
A Deploy can only be included in a Block between timestamp and timestamp + ttl.
Input examples: ‘1hr 12min’, ‘30min 50sec’, ‘1day’.
See humantime::parse_duration for more information.
chain_name: &'a strName of the chain, to avoid the Deploy from being accidentally or maliciously included in
a different chain.
session_account: &'a strThe hex-encoded public key of the account context under which the session code will be executed.
If session_account is empty, the account’s public key will be derived from the provided
secret_key. It is an error for both fields to be empty.
gas_price_tolerance: &'a strGas price for the deploy.