Enum Error

pub enum Error {
Show 17 variants DeploySizeTooLarge { max_deploy_size: u32, actual_deploy_size: usize, }, DeployMissingPaymentCode, InvalidKeyVariant { expected_variant: String, actual: Key, }, FailedToGetResponse { rpc_id: JsonRpcId, rpc_method: &'static str, error: Error, }, ResponseIsHttpError { rpc_id: JsonRpcId, rpc_method: &'static str, error: Error, }, FailedToParseResponse { rpc_id: JsonRpcId, rpc_method: &'static str, error: Error, }, ResponseIsRpcError { rpc_id: JsonRpcId, rpc_method: &'static str, error: Error, }, InvalidRpcResponse { rpc_id: JsonRpcId, rpc_method: &'static str, response_kind: &'static str, response: Value, source: Option<Error>, }, FailedToEncodeToJson { context: &'static str, error: Error, }, FailedToDecodeFromJson { context: &'static str, error: Error, }, FileAlreadyExists(PathBuf), EmptyKeygenPath, UnsupportedAlgorithm(String), IoError { context: String, error: Error, }, ToBytesError(Error), CryptoError { context: &'static str, error: ErrorExt, }, ResponseFailedValidation(ValidateResponseError),
}
Errors that may be returned by casper_client functions.

Variants



DeploySizeTooLarge

Deploy size too large.

Fields

max_deploy_size: u32

The maximum permitted serialized deploy size, in bytes.

actual_deploy_size: usize

The serialized size of the deploy provided, in bytes.



DeployMissingPaymentCode

Failed to build Deploy due to missing payment code.

Call DeployBuilder::with_standard_payment or DeployBuilder::with_payment before calling DeployBuilder::build.



InvalidKeyVariant

Invalid Key variant.

Fields

expected_variant: String

The expected variant.

actual: Key

The actual key provided.



FailedToGetResponse

Failed to get a response from the node.

Fields

rpc_id: JsonRpcId

The JSON-RPC ID.

rpc_method: &'static str

The JSON-RPC request method.

error: Error

The reported error.



ResponseIsHttpError

JSON-RPC error returned from the node.

Fields

rpc_id: JsonRpcId

The JSON-RPC ID.

rpc_method: &'static str

The JSON-RPC request method.

error: Error

The reported error.



FailedToParseResponse

Failed to parse the response.

Fields

rpc_id: JsonRpcId

The JSON-RPC ID.

rpc_method: &'static str

The JSON-RPC request method.

error: Error

The reported error.



ResponseIsRpcError

JSON-RPC error returned from the node.

Fields

rpc_id: JsonRpcId

The JSON-RPC ID.

rpc_method: &'static str

The JSON-RPC request method.

error: Error

The reported error.



InvalidRpcResponse

Invalid response returned from the node.

Fields

rpc_id: JsonRpcId

The JSON-RPC ID.

rpc_method: &'static str

The JSON-RPC request method.

response_kind: &'static str

What kind of Json response was received.

response: Value

The JSON response.

source: Option<Error>

If available, the original error from Serde.



FailedToEncodeToJson

Failed to encode to JSON.

Fields

context: &'static str

Contextual description of where this error occurred.

error: Error

Underlying encoding error.



FailedToDecodeFromJson

Failed to decode from JSON.

Fields

context: &'static str

Contextual description of where this error occurred.

error: Error

Underlying decoding error.



FileAlreadyExists(PathBuf)

Failed to create new file because it already exists.



EmptyKeygenPath

Empty path provided as output dir for keygen.



UnsupportedAlgorithm(String)

Unsupported keygen algorithm.



IoError

Context-adding wrapper for std::io::Error.

Fields

context: String

Contextual description of where this error occurred including relevant paths, filenames, etc.

error: Error

std::io::Error raised during the operation in question.



ToBytesError(Error)

Failed to serialize to bytes.



CryptoError

Cryptographic error.

Fields

context: &'static str

Contextual description of where this error occurred including relevant paths, filenames, etc.

error: ErrorExt

Underlying crypto error.



ResponseFailedValidation(ValidateResponseError)

Failed to validate response.