pub enum JsonRpcId {
Number(i64),
String(String),
}Expand description
An identifier for a JSON-RPC, provided by the client and returned in the response.
The JSON-RPC spec allows for NULL to be used as the RPC-ID to imply a client notification, but the Casper node JSON-RPC server does not provide any such notification endpoints, so this is not supported here.
Variants