Enum OutputKind

pub enum OutputKind<'a> {
    File {
        path: &'a Path,
        tmp_path: PathBuf,
        overwrite_if_exists: bool,
    },
    Stdout,
}
An output abstraction for associating a Write object with some metadata.

Variants



File

An output file.

Fields

path: &'a Path

The path of the output file.

tmp_path: PathBuf

The path to a temporary file in the same directory as the output file, which is used to make the write operation transactional and ensures that the file at path is not damaged if it pre-exists.

overwrite_if_exists: bool

If overwrite_if_exists is true, then the file at path will be overwritten.



Stdout

Stdout.

Implementations

Source

impl<'a> OutputKind<'a>

pub fn file(path: &'a Path, overwrite_if_exists: bool) -> Self

Returns a new OutputKind::File.