pub enum ValidateResponseError {
BytesRepr(Error),
Serde(Error),
ValidateResponseFailedToParse,
BodyHashMismatch {
block: Box<Block>,
actual_block_body_hash: Digest,
},
BlockHashMismatch {
block: Box<Block>,
actual_block_header_hash: BlockHash,
},
SerializedValueNotContainedInProof,
NoBlockInResponse,
UnexpectedBlockHash,
UnexpectedBlockHeight,
InvalidGlobalStateResponse,
}Expand description
Error that can be returned when validating data returned from a JSON-RPC method.
Variants
BytesRepr(Error)
Failed to marshall value.
Serde(Error)
Error from serde.
ValidateResponseFailedToParse
Failed to parse JSON.
BodyHashMismatch
The body hash in the header is not the same as the hash of the body of the block.
Fields
BlockHashMismatch
The block’s hash is not the same as the header’s hash.
Fields
SerializedValueNotContainedInProof
Serialized value not contained in proof.
NoBlockInResponse
No block in response.
UnexpectedBlockHash
Block hash requested does not correspond to response.
UnexpectedBlockHeight
Block height was not as requested.
InvalidGlobalStateResponse
An invalid combination of state identifier and block header response