pub enum Verbosity {
Low = 0,
Medium = 1,
High = 2,
}Expand description
The level of verbosity of the output to stdout.
Variants
Low = 0
Minimal output.
Medium = 1
Moderate amount of output, with any long hex strings shortened to a string indicating the character count of the string.
High = 2
High level of output, with all fields displayed in full.