get_deploy

Function get_deploy 

pub async fn get_deploy(
    rpc_id: JsonRpcId,
    node_address: &str,
    verbosity: Verbosity,
    deploy_hash: DeployHash,
    finalized_approvals: bool,
) -> Result<SuccessResponse<GetDeployResult>, Error>
Retrieves a Deploy and its metadata (i.e. execution results) from the network.

Sends a JSON-RPC info_get_deploy request to the specified node.

finalized_approvals defines whether to return the Deploy with its approvals as finalized by consensus of the validators on the network, or as originally received by the specified node.

For details of the other parameters, see the module docs.