output_deploy

Function output_deploy 

pub fn output_deploy(
    output: OutputKind<'_>,
    deploy: &Deploy,
) -> Result<(), Error>
👎Deprecated since 3.0.0: use output_transaction instead
Outputs a Deploy to a file or stdout.

As a file, the Deploy can subsequently be signed by other parties using sign_deploy_file and then read and sent to the network for execution using read_deploy_file and put_deploy respectively.

output specifies the output file and corresponding overwrite behaviour, or if OutputKind::Stdout, causes the Deploy to be printed stdout.