Module keygen

Cryptographic key generation.

Constants

ED25519
Name of Ed25519 algorithm.
FILES
List of keygen related filenames: “secret_key.pem”, “public_key.pem” and “public_key_hex”.
PUBLIC_KEY_HEX
Default filename for the hex-encoded public key file.
PUBLIC_KEY_PEM
Default filename for the PEM-encoded public key file.
SECP256K1
Name of secp256k1 algorithm.
SECRET_KEY_PEM
Default filename for the PEM-encoded secret key file.

Functions

generate_files
Generates a new asymmetric key pair using the specified algorithm, and writes them to files in the specified directory.