DictionaryItemIdentifier

Enum DictionaryItemIdentifier 

pub enum DictionaryItemIdentifier {
    AccountNamedKey {
        key: String,
        dictionary_name: String,
        dictionary_item_key: String,
    },
    ContractNamedKey {
        key: String,
        dictionary_name: String,
        dictionary_item_key: String,
    },
    EntityNamedKey {
        key: String,
        dictionary_name: String,
        dictionary_item_key: String,
    },
    URef {
        seed_uref: URef,
        dictionary_item_key: String,
    },
    Dictionary(String),
}
The identifier for a dictionary item.

Variants



AccountNamedKey

A dictionary item identified via an Key::Account’s named keys.

Fields

key: String

The Key::Account as a formatted string, identifying the account whose named keys contains dictionary_name.

dictionary_name: String

The named key under which the dictionary seed URef is stored.

dictionary_item_key: String

The key within the dictionary under which the item is held.



ContractNamedKey

A dictionary item identified via a Key::Hash’s named keys.

Fields

key: String

The Key::Hash as a formatted string, identifying the contract whose named keys contains dictionary_name.

dictionary_name: String

The named key under which the dictionary seed URef is stored.

dictionary_item_key: String

The key within the dictionary under which the item is held.



EntityNamedKey

A dictionary item identified via a Key::AddressableEntity’s named keys.

Fields

key: String

The Key::AddressableEntity as a formatted string, identifying the entity whose named keys contain dictionary_name.

dictionary_name: String

The named key under which the dictionary seed URef is stored.

dictionary_item_key: String

The key within the dictionary under which the item is held.



URef

A dictionary item identified via its seed Key::URef.

Fields

seed_uref: URef

The dictionary’s seed URef.

dictionary_item_key: String

The key within the dictionary under which the item is held.



Dictionary(String)

A dictionary item identified via its unique address derived from the dictionary’s seed URef and the item’s key within the dictionary. The key must be a Key::Dictionary variant, as a formatted string.

Implementations

Source

impl DictionaryItemIdentifier

pub fn new_from_account_info( account_hash: AccountHash, dictionary_name: String, dictionary_item_key: String, ) -> Self

Returns a new DictionaryItemIdentifier::AccountNamedKey variant.

pub fn new_from_contract_info( contract_addr: HashAddr, dictionary_name: String, dictionary_item_key: String, ) -> Self

Returns a new DictionaryItemIdentifier::ContractNamedKey variant.

pub fn new_from_entity_info( entity_addr: EntityAddr, dictionary_name: String, dictionary_item_key: String, ) -> Self

Returns a new DictionaryItemIdentifier::EntityNamedKey variant.

pub fn new_from_seed_uref(seed_uref: URef, dictionary_item_key: String) -> Self

Returns a new DictionaryItemIdentifier::URef variant.

pub fn new_from_item_key(item_key: Key) -> Result<Self, Error>

Returns a new DictionaryItemIdentifier::Dictionary variant.