pub enum PurseIdentifier {
MainPurseUnderPublicKey(PublicKey),
MainPurseUnderAccountHash(AccountHash),
MainPurseUnderEntityAddr(EntityAddr),
PurseUref(URef),
}Expand description
Identifier of a purse.
Variants
MainPurseUnderPublicKey(PublicKey)
The main purse of the account identified by this public key.
MainPurseUnderAccountHash(AccountHash)
The main purse of the account identified by this account hash.
MainPurseUnderEntityAddr(EntityAddr)
The main purse of the account identified by this entity address.
PurseUref(URef)
The purse identified by this URef.