pub struct Method {
pub name: String,
pub summary: String,
pub params: Vec<SchemaParam>,
pub result: ResponseResult,
pub examples: Vec<Example>,
}Expand description
Describes the interface for the given method name. The method name is used as the method
field of the JSON-RPC body.
Fields
name: StringThe method name.
summary: StringA short summary of what the method does.
params: Vec<SchemaParam>A list of parameters that are applicable for this method.
result: ResponseResultThe description of the result returned by the method.
examples: Vec<Example>An array of examples.