Module types

Module types 

Various data types of the Casper network.

Structs

AuctionState
The state associated with the auction system contract as at the given block height and corresponding state root hash.
DeployExecutionInfo
The block hash and height in which a given deploy was executed, along with the execution result if known.
JsonBlockWithSignatures
A JSON-friendly representation of a block and the signatures for that block.
LegacyExecutionResult
The execution result of a single deploy.