pub struct AuctionState { /* private fields */ }Expand description
The state associated with the auction system contract as at the given block height and corresponding state root hash.
Implementations
Sourceimpl AuctionState
impl AuctionState
Sourcepub fn state_root_hash(&self) -> &Digest
pub fn state_root_hash(&self) -> &Digest
Returns the state root hash applicable to this auction state.
Sourcepub fn block_height(&self) -> u64
pub fn block_height(&self) -> u64
Returns the block height applicable to this auction state.
Sourcepub fn era_validators(&self) -> impl Iterator<Item = &EraValidators>
pub fn era_validators(&self) -> impl Iterator<Item = &EraValidators>
Returns the validators for the applicable era.
Sourcepub fn bids(&self) -> impl Iterator<Item = &BidderAndBid>
pub fn bids(&self) -> impl Iterator<Item = &BidderAndBid>
Returns the bids for the applicable era.