pub struct Bid { /* private fields */ }Expand description
A representation of a single bid, containing most of the info in
casper_types::system::auction::Bid.
Implementations
Sourceimpl Bid
impl Bid
Sourcepub fn bonding_purse(&self) -> &URef
pub fn bonding_purse(&self) -> &URef
Returns the purse that was used for bonding.
Sourcepub fn staked_amount(&self) -> U512
pub fn staked_amount(&self) -> U512
Returns the amount of tokens staked by a validator (not including delegators).
Sourcepub fn delegation_rate(&self) -> u8
pub fn delegation_rate(&self) -> u8
Returns the validator’s specified delegation rate.
Sourcepub fn delegators(&self) -> impl Iterator<Item = &Delegator>
pub fn delegators(&self) -> impl Iterator<Item = &Delegator>
Returns the delegators associated with this validator’s bid.