pub enum ExecutableDeployItem {
ModuleBytes {
module_bytes: Bytes,
args: RuntimeArgs,
},
StoredContractByHash {
hash: ContractHash,
entry_point: String,
args: RuntimeArgs,
},
StoredContractByName {
name: String,
entry_point: String,
args: RuntimeArgs,
},
StoredVersionedContractByHash {
hash: ContractPackageHash,
version: Option<ContractVersion>,
entry_point: String,
args: RuntimeArgs,
},
StoredVersionedContractByName {
name: String,
version: Option<ContractVersion>,
entry_point: String,
args: RuntimeArgs,
},
Transfer {
args: RuntimeArgs,
},
}Expand description
The payment or session code of a Deploy.
Variants
ModuleBytes
Raw bytes of compiled Wasm code, which must include a call entry point, and the arguments
to call at runtime.
Fields
args: RuntimeArgsThe arguments to be passed to the entry point at runtime.
StoredContractByHash
A contract stored in global state, referenced by its “hash”, along with the entry point and arguments to call at runtime.
Fields
hash: ContractHashThe contract’s identifier.
args: RuntimeArgsThe arguments to be passed to the entry point at runtime.
StoredContractByName
A contract stored in global state, referenced by a named key existing in the Deploy’s
account context, along with the entry point and arguments to call at runtime.
Fields
args: RuntimeArgsThe arguments to be passed to the entry point at runtime.
StoredVersionedContractByHash
A versioned contract stored in global state, referenced by its “hash”, along with the entry point and arguments to call at runtime.
Fields
hash: ContractPackageHashThe contract package’s identifier.
version: Option<ContractVersion>The version of the contract to call. If None, the highest enabled version is used.
args: RuntimeArgsThe arguments to be passed to the entry point at runtime.
StoredVersionedContractByName
A versioned contract stored in global state, referenced by a named key existing in the
Deploy’s account context, along with the entry point and arguments to call at runtime.
Fields
version: Option<ContractVersion>The version of the contract to call. If None, the highest enabled version is used.
args: RuntimeArgsThe arguments to be passed to the entry point at runtime.
Transfer
A native transfer which does not contain or reference any Wasm code.
Fields
args: RuntimeArgsThe arguments to be passed to the native transfer entry point at runtime.
Implementations
Sourceimpl ExecutableDeployItem
impl ExecutableDeployItem
Sourcepub fn new_module_bytes(module_bytes: Bytes, args: RuntimeArgs) -> Self
pub fn new_module_bytes(module_bytes: Bytes, args: RuntimeArgs) -> Self
Returns a new ExecutableDeployItem::ModuleBytes.
Sourcepub fn new_standard_payment<A: Into<U512>>(amount: A) -> Self
pub fn new_standard_payment<A: Into<U512>>(amount: A) -> Self
Returns a new ExecutableDeployItem::ModuleBytes suitable for use as standard payment code
of a Deploy.
Sourcepub fn new_stored_contract_by_hash(
hash: ContractHash,
entry_point: String,
args: RuntimeArgs,
) -> Self
pub fn new_stored_contract_by_hash( hash: ContractHash, entry_point: String, args: RuntimeArgs, ) -> Self
Returns a new ExecutableDeployItem::StoredContractByHash.
Sourcepub fn new_stored_contract_by_name(
name: String,
entry_point: String,
args: RuntimeArgs,
) -> Self
pub fn new_stored_contract_by_name( name: String, entry_point: String, args: RuntimeArgs, ) -> Self
Returns a new ExecutableDeployItem::StoredContractByName.
Sourcepub fn new_stored_versioned_contract_by_hash(
hash: ContractPackageHash,
version: Option<ContractVersion>,
entry_point: String,
args: RuntimeArgs,
) -> Self
pub fn new_stored_versioned_contract_by_hash( hash: ContractPackageHash, version: Option<ContractVersion>, entry_point: String, args: RuntimeArgs, ) -> Self
Returns a new ExecutableDeployItem::StoredVersionedContractByHash.
Sourcepub fn new_stored_versioned_contract_by_name(
name: String,
version: Option<ContractVersion>,
entry_point: String,
args: RuntimeArgs,
) -> Self
pub fn new_stored_versioned_contract_by_name( name: String, version: Option<ContractVersion>, entry_point: String, args: RuntimeArgs, ) -> Self
Returns a new ExecutableDeployItem::StoredVersionedContractByName.
Sourcepub fn new_transfer<A: Into<U512>>(
amount: A,
maybe_source: Option<URef>,
target: TransferTarget,
maybe_transfer_id: Option<u64>,
) -> Self
pub fn new_transfer<A: Into<U512>>( amount: A, maybe_source: Option<URef>, target: TransferTarget, maybe_transfer_id: Option<u64>, ) -> Self
Returns a new ExecutableDeployItem suitable for use as session code for a transfer.
If maybe_source is None, the account’s main purse is used as the source.