Struct AssociatedKey

pub struct AssociatedKey { /* private fields */ }
A representation of a public key and weight which can be associated with a given Account or Contract.

Note, the “key” in this case is represented by an AccountHash.

Implementations

Source

impl AssociatedKey

pub fn account_hash(&self) -> &AccountHash

Returns the account hash of this associated key.

pub fn weight(&self) -> u8

Returns the weight attributed to this associated key.