Struct BlockHash

pub struct BlockHash(/* private fields */);
A cryptographic hash uniquely identifying a Block.

Note

The type of this field is currently the same for all versions of blocks, and furthermore it is always a hash over the block’s header. However, how the hash is calculated can be different.

There are two separate functions to allow for validation of the block given the different hash mechanisms: validate_block_hashes_v1 and validate_block_hashes_v2.

Implementations

Source

impl BlockHash

pub fn new(digest: Digest) -> Self

Returns a new BlockHash.

pub fn inner(&self) -> Digest

Returns a copy of the wrapped Digest.