pub struct BlockHeader { /* private fields */ }Expand description
The header portion of a Block.
Implementations
Sourceimpl BlockHeader
impl BlockHeader
Sourcepub fn parent_hash(&self) -> BlockHash
pub fn parent_hash(&self) -> BlockHash
Returns the parent block’s hash.
Sourcepub fn state_root_hash(&self) -> Digest
pub fn state_root_hash(&self) -> Digest
Returns the root hash of global state after executing the deploys in this block.
Sourcepub fn body_hash(&self) -> Digest
pub fn body_hash(&self) -> Digest
Returns the hash of the body of this block.
Note
See validate_block_hashes_v1 and validate_block_hashes_v2 for further details on the
different ways in which this hash can be calculated.
Sourcepub fn random_bit(&self) -> bool
pub fn random_bit(&self) -> bool
Returns the random bit held in this block.
Sourcepub fn accumulated_seed(&self) -> Digest
pub fn accumulated_seed(&self) -> Digest
Returns the accumulated seed held in this block.
Sourcepub fn era_end(&self) -> Option<&EraEnd>
pub fn era_end(&self) -> Option<&EraEnd>
Returns the EraEnd, where Some means this is a “switch block”, i.e. the final block of
the specified era.
Sourcepub fn protocol_version(&self) -> ProtocolVersion
pub fn protocol_version(&self) -> ProtocolVersion
Returns the protocol version of the network at the time this block was created.