pub struct Deploy { /* private fields */ }Expand description
A signed item sent to the network used to request execution of Wasm.
Note that constructing a Deploy is done via the DeployBuilder.
Implementations
Sourceimpl Deploy
impl Deploy
Sourcepub const DEFAULT_TTL: TimeDiff
pub const DEFAULT_TTL: TimeDiff
The default time-to-live for Deploys, i.e. 30 minutes.
Sourcepub const DEFAULT_GAS_PRICE: u64 = 1u64
pub const DEFAULT_GAS_PRICE: u64 = 1u64
The default gas price for Deploys, i.e. 1.
Sourcepub fn sign(&mut self, secret_key: &SecretKey)
pub fn sign(&mut self, secret_key: &SecretKey)
Adds a signature of this deploy’s hash to its approvals.
Sourcepub fn is_valid_size(&self, max_deploy_size: u32) -> Result<(), Error>
pub fn is_valid_size(&self, max_deploy_size: u32) -> Result<(), Error>
Returns Ok if the serialized size of the deploy is not greater than max_deploy_size.
Sourcepub fn id(&self) -> &DeployHash
pub fn id(&self) -> &DeployHash
Returns the hash uniquely identifying this deploy.
Sourcepub fn header(&self) -> &DeployHeader
pub fn header(&self) -> &DeployHeader
Returns the header portion of the deploy.
Sourcepub fn payment(&self) -> &ExecutableDeployItem
pub fn payment(&self) -> &ExecutableDeployItem
Returns the payment code of the deploy.
Sourcepub fn session(&self) -> &ExecutableDeployItem
pub fn session(&self) -> &ExecutableDeployItem
Returns the session code of the deploy.