Struct DeployBuilder

pub struct DeployBuilder<'a> { /* private fields */ }
A builder for constructing a Deploy.

Implementations

Source

impl<'a> DeployBuilder<'a>

pub fn new<C: Into<String>>( chain_name: C, session: ExecutableDeployItem, secret_key: &'a SecretKey, ) -> Self

Returns a new DeployBuilder.

Note

Before calling build, you must ensure that payment code is provided by either calling with_standard_payment or with_payment.

pub fn new_transfer<C: Into<String>, A: Into<U512>>( chain_name: C, amount: A, maybe_source: Option<URef>, target: TransferTarget, maybe_transfer_id: Option<u64>, secret_key: &'a SecretKey, ) -> Self

Returns a new DeployBuilder with session code suitable for a transfer.

If maybe_source is None, the account’s main purse is used as the source of the transfer.

Note

Before calling build, you must ensure that payment code is provided by either calling with_standard_payment or with_payment.

pub fn with_standard_payment<A: Into<U512>>(self, amount: A) -> Self

Sets the payment in the Deploy to a standard payment with the given amount.

pub fn with_payment(self, payment: ExecutableDeployItem) -> Self

Sets the payment in the Deploy.

pub fn with_account(self, account: PublicKey) -> Self

Sets the account in the Deploy.

If not provided, the public key derived from the secret key used in the DeployBuilder will be used as the account in the Deploy.

pub fn with_timestamp(self, timestamp: Timestamp) -> Self

Sets the timestamp in the Deploy.

If not provided, the timestamp will be set to the time when the DeployBuilder was constructed.

pub fn with_ttl(self, ttl: TimeDiff) -> Self

Sets the ttl (time-to-live) in the Deploy.

If not provided, the ttl will be set to Deploy::DEFAULT_TTL.

pub fn build(self) -> Result<Deploy, Error>

Returns the new Deploy, or an error if neither with_standard_payment nor with_payment were previously called.