pub struct DeployHeader { /* private fields */ }Expand description
The header portion of a Deploy.
Implementations
Sourceimpl DeployHeader
impl DeployHeader
Sourcepub fn dependencies(&self) -> impl Iterator<Item = &DeployHash>
pub fn dependencies(&self) -> impl Iterator<Item = &DeployHash>
Returns the list of other deploys that have to be run before this one.
Sourcepub fn chain_name(&self) -> &str
pub fn chain_name(&self) -> &str
Returns the chain name of the network the deploy is supposed to be run on.