pub struct EraReport { /* private fields */ }Expand description
Equivocation and reward information included in switch blocks.
Implementations
Sourceimpl EraReport
impl EraReport
Sourcepub fn equivocators(&self) -> impl Iterator<Item = &PublicKey>
pub fn equivocators(&self) -> impl Iterator<Item = &PublicKey>
Returns the collection of validators which have equivocated in this era.
Sourcepub fn inactive_validators(&self) -> impl Iterator<Item = &PublicKey>
pub fn inactive_validators(&self) -> impl Iterator<Item = &PublicKey>
Returns the collection of validators which were marked inactive in this era.