pub async fn send_deploy_file(
maybe_rpc_id: &str,
node_address: &str,
verbosity_level: u64,
input_path: &str,
) -> Result<SuccessResponse<PutDeployResult>, CliError>Expand description
Reads a previously-saved Deploy from a file and sends it to the network for execution.
For details of the parameters, see the module docs.