pub fn sign_deploy_file(
input_path: &str,
secret_key_path: &str,
maybe_output_path: &str,
force: bool,
) -> Result<(), CliError>Expand description
Reads a previously-saved Deploy from a file, cryptographically signs it, and outputs it to a
file or stdout.
maybe_output_path specifies the output file path, or if empty, will print it to stdout. If
force is true, and a file exists at maybe_output_path, it will be overwritten. If force
is false and a file exists at maybe_output_path, crate::Error::FileAlreadyExists is returned
and the file will not be written.