pub async fn speculative_transfer(
maybe_rpc_id: &str,
node_address: &str,
verbosity_level: u64,
amount: &str,
target_account: &str,
transfer_id: &str,
deploy_params: DeployStrParams<'_>,
payment_params: PaymentStrParams<'_>,
) -> Result<SuccessResponse<SpeculativeExecResult>, CliError>Expand description
Creates a Deploy to transfer funds between purses, and sends it to the specified node for
speculative execution.
amountis a string to be parsed as aU512specifying the amount to be transferred.target_accountis theAccountHash,UReforPublicKeyof the account to which the funds will be transferred, formatted as a hex-encoded string. The account’s main purse will receive the funds.transfer_idis a string to be parsed as au64representing a user-defined identifier which will be permanently associated with the transfer.
For details of other parameters, see the module docs.