pub enum DictionaryItemStrParams<'a> {
AccountNamedKey {
account_hash: &'a str,
dictionary_name: &'a str,
dictionary_item_key: &'a str,
},
ContractNamedKey {
hash_addr: &'a str,
dictionary_name: &'a str,
dictionary_item_key: &'a str,
},
URef {
seed_uref: &'a str,
dictionary_item_key: &'a str,
},
Dictionary(&'a str),
}Expand description
Various ways of uniquely identifying a dictionary item.
Variants
AccountNamedKey
A dictionary item identified via an Account’s named keys.
Fields

account_hash: &'a strThe AccountHash as a formatted string, identifying the account whose named keys
contains dictionary_name.
ContractNamedKey
A dictionary item identified via a Contract’s named keys.
Fields
URef
A dictionary item identified via its seed URef.
Fields
Dictionary(&'a str)
A dictionary item identified via its unique address derived from the dictionary’s seed
URef and the item’s key within the dictionary. The key must be a Key::Dictionary
variant as a formatted string.