pub async fn get_account(
maybe_rpc_id: &str,
node_address: &str,
verbosity_level: u64,
maybe_block_id: &str,
public_key: &str,
) -> Result<SuccessResponse<GetAccountResult>, CliError>Expand description
Retrieves an Account at a given Block.
public_key is the public key as a formatted string associated with the Account.
For details of other parameters, see the module docs.