pub async fn get_dictionary_item(
maybe_rpc_id: &str,
node_address: &str,
verbosity_level: u64,
state_root_hash: &str,
dictionary_item_str_params: DictionaryItemStrParams<'_>,
) -> Result<SuccessResponse<GetDictionaryItemResult>, CliError>Expand description
Retrieves a StoredValue from a dictionary at a given state root hash.
state_root_hash must be a hex-encoded, 32-byte hash digest.
dictionary_item_str_params contains dictionary item identifier options for this query. See
DictionaryItemStrParams for more details.
For details of other parameters, see the module docs.