pub async fn get_entity(
maybe_rpc_id: &str,
node_address: &str,
verbosity_level: u64,
maybe_block_id: &str,
entity_identifier: &str,
) -> Result<SuccessResponse<GetAddressableEntityResult>, CliError>Expand description
Retrieves an crate::rpcs::v2_0_0::get_entity::EntityOrAccount at a given Block.
For details of other parameters, see the module docs.
Parameters
maybe_rpc_id: The optional RPC ID as a string slice.node_address: The address of the node as a string slice.verbosity_level: The verbosity level as a 64-bit unsigned integer.maybe_block_id: The optional block ID as a string slice.entity_identifier: The entity identifier as a string slice.
Returns
The result containing either a successful response with the entity details or a CliError.