pub async fn get_state_root_hash(
maybe_rpc_id: &str,
node_address: &str,
verbosity_level: u64,
maybe_block_id: &str,
) -> Result<SuccessResponse<GetStateRootHashResult>, CliError>Expand description
Retrieves a state root hash at a given Block.
For details of the parameters, see the module docs.