pub async fn put_transaction(
rpc_id_str: &str,
node_address: &str,
verbosity_level: u64,
builder_params: TransactionBuilderParams<'_>,
transaction_params: TransactionStrParams<'_>,
) -> Result<SuccessResponse<PutTransactionResult>, CliError>Expand description
Creates a Transaction and sends it to the network for execution.
rpc_id_str is the RPC ID to use for this request.
node_address is the address of the node to send the request to.
verbosity_level is the level of verbosity to use when outputting the response.