pub async fn query_global_state(
maybe_rpc_id: &str,
node_address: &str,
verbosity_level: u64,
maybe_block_id: &str,
maybe_state_root_hash: &str,
key: &str,
path: &str,
) -> Result<SuccessResponse<QueryGlobalStateResult>, CliError>Expand description
Retrieves a StoredValue from global state.
maybe_block_id or maybe_state_root_hash identify the global state root hash to be used for
the query. Exactly one of these args should be an empty string.
key must be a formatted PublicKey or Key. path is comprised of components starting
from the key, separated by /s. It may be empty.
For details of other parameters, see the module docs.