This module contains structs and helpers which are used by multiple subcommands related to creating deploys.
Functions
- account_
identifier account_identifiercan be a formatted public key, in the form of a hex-formatted string, a pem file, or a file containing a hex formatted string, or a formatted string representing an account hash. It may not be empty.- args_
from_ simple_ or_ json - Constructs a
RuntimeArgsinstance from either simple or JSON representation. - entity_
identifier entity_identifiercan be a formatted public key, in the form of a hex-formatted string, a pem file, or a file containing a hex formatted string, or a formatted string representing an account hash. It may not be empty.- purse_
identifier purse_idcan be a formatted public key, account hash, or URef. It may not be empty.- transaction_
module_ bytes - Parse a transaction file into Bytes to be used in crafting a new session transaction
- transfer_
target - Parses transfer target from a string for use with the transaction builder
- uref
- Parses a URef from a formatted string for the purposes of creating transactions.