pub fn account_identifier(
account_identifier: &str,
) -> Result<AccountIdentifier, CliError>Expand description
account_identifier can be a formatted public key, in the form of a hex-formatted string,
a pem file, or a file containing a hex formatted string, or a formatted string representing
an account hash. It may not be empty.