pub enum Error {
Show 17 variants
DeploySizeTooLarge {
max_deploy_size: u32,
actual_deploy_size: usize,
},
DeployMissingPaymentCode,
InvalidKeyVariant {
expected_variant: String,
actual: Key,
},
FailedToGetResponse {
rpc_id: JsonRpcId,
rpc_method: &'static str,
error: Error,
},
ResponseIsHttpError {
rpc_id: JsonRpcId,
rpc_method: &'static str,
error: Error,
},
FailedToParseResponse {
rpc_id: JsonRpcId,
rpc_method: &'static str,
error: Error,
},
ResponseIsRpcError {
rpc_id: JsonRpcId,
rpc_method: &'static str,
error: Error,
},
InvalidRpcResponse {
rpc_id: JsonRpcId,
rpc_method: &'static str,
response_kind: &'static str,
response: Value,
source: Option<Error>,
},
FailedToEncodeToJson {
context: &'static str,
error: Error,
},
FailedToDecodeFromJson {
context: &'static str,
error: Error,
},
FileAlreadyExists(PathBuf),
EmptyKeygenPath,
UnsupportedAlgorithm(String),
IoError {
context: String,
error: Error,
},
ToBytesError(Error),
CryptoError {
context: &'static str,
error: ErrorExt,
},
ResponseFailedValidation(ValidateResponseError),
}Expand description
Errors that may be returned by casper_client functions.
Variants
DeploySizeTooLarge
Deploy size too large.
Fields
DeployMissingPaymentCode
Failed to build Deploy due to missing payment code.
Call DeployBuilder::with_standard_payment or DeployBuilder::with_payment before
calling DeployBuilder::build.
InvalidKeyVariant
Invalid Key variant.
FailedToGetResponse
Failed to get a response from the node.
Fields
ResponseIsHttpError
JSON-RPC error returned from the node.
Fields
FailedToParseResponse
Failed to parse the response.
Fields
ResponseIsRpcError
JSON-RPC error returned from the node.
Fields
InvalidRpcResponse
Invalid response returned from the node.
Fields
FailedToEncodeToJson
Failed to encode to JSON.
Fields
FailedToDecodeFromJson
Failed to decode from JSON.
Fields
FileAlreadyExists(PathBuf)
Failed to create new file because it already exists.
EmptyKeygenPath
Empty path provided as output dir for keygen.
UnsupportedAlgorithm(String)
Unsupported keygen algorithm.
IoError
Context-adding wrapper for std::io::Error.
Fields
ToBytesError(Error)
Failed to serialize to bytes.
CryptoError
Cryptographic error.
Fields
ResponseFailedValidation(ValidateResponseError)
Failed to validate response.