Cryptographic key generation.
Constants
- ED25519
- Name of Ed25519 algorithm.
- FILES
- List of keygen related filenames: “secret_key.pem”, “public_key.pem” and “public_key_hex”.
- PUBLIC_
KEY_ HEX - Default filename for the hex-encoded public key file.
- PUBLIC_
KEY_ PEM - Default filename for the PEM-encoded public key file.
- SECP256
K1 - Name of secp256k1 algorithm.
- SECRET_
KEY_ PEM - Default filename for the PEM-encoded secret key file.
Functions
- generate_
files - Generates a new asymmetric key pair using the specified algorithm, and writes them to files in the specified directory.