pub enum DictionaryItemIdentifier {
AccountNamedKey {
key: String,
dictionary_name: String,
dictionary_item_key: String,
},
ContractNamedKey {
key: String,
dictionary_name: String,
dictionary_item_key: String,
},
URef {
seed_uref: URef,
dictionary_item_key: String,
},
Dictionary(String),
}Expand description
The identifier for a dictionary item.
Variants
AccountNamedKey
A dictionary item identified via an Account’s named keys.
Fields

key: StringThe Key::Account as a formatted string, identifying the account whose named keys
contains dictionary_name.
ContractNamedKey
A dictionary item identified via a Contract’s named keys.
Fields
URef
A dictionary item identified via its seed URef.
Fields
Dictionary(String)
A dictionary item identified via its unique address derived from the dictionary’s seed
URef and the item’s key within the dictionary. The key must be a Key::Dictionary
variant, as a formatted string.
Implementations
Sourceimpl DictionaryItemIdentifier
impl DictionaryItemIdentifier
Sourcepub fn new_from_account_info(
account_hash: AccountHash,
dictionary_name: String,
dictionary_item_key: String,
) -> Self
pub fn new_from_account_info( account_hash: AccountHash, dictionary_name: String, dictionary_item_key: String, ) -> Self
Returns a new DictionaryItemIdentifier::AccountNamedKey variant.
Sourcepub fn new_from_contract_info(
contract_addr: HashAddr,
dictionary_name: String,
dictionary_item_key: String,
) -> Self
pub fn new_from_contract_info( contract_addr: HashAddr, dictionary_name: String, dictionary_item_key: String, ) -> Self
Returns a new DictionaryItemIdentifier::ContractNamedKey variant.
Sourcepub fn new_from_seed_uref(seed_uref: URef, dictionary_item_key: String) -> Self
pub fn new_from_seed_uref(seed_uref: URef, dictionary_item_key: String) -> Self
Returns a new DictionaryItemIdentifier::URef variant.
Sourcepub fn new_from_item_key(item_key: Key) -> Result<Self, Error>
pub fn new_from_item_key(item_key: Key) -> Result<Self, Error>
Returns a new DictionaryItemIdentifier::Dictionary variant.