pub struct GetNodeStatusResult {Show 14 fields
pub api_version: ProtocolVersion,
pub chainspec_name: String,
pub starting_state_root_hash: Digest,
pub peers: Vec<PeerEntry>,
pub last_added_block_info: Option<MinimalBlockInfo>,
pub our_public_signing_key: Option<PublicKey>,
pub round_length: Option<TimeDiff>,
pub next_upgrade: Option<NextUpgrade>,
pub build_version: String,
pub uptime: TimeDiff,
pub reactor_state: ReactorState,
pub last_progress: Timestamp,
pub available_block_range: AvailableBlockRange,
pub block_sync: BlockSynchronizerStatus,
}Expand description
The result field of a successful JSON-RPC response to a info_get_status request.
Fields
api_version: ProtocolVersionThe JSON-RPC server version.
chainspec_name: StringThe chainspec name.
starting_state_root_hash: Digest👎Deprecated since 1.5.0
The state root hash used at the start of the current session.
peers: Vec<PeerEntry>The node ID and network address of each connected peer.
last_added_block_info: Option<MinimalBlockInfo>The minimal info of the last block from the linear chain.
our_public_signing_key: Option<PublicKey>The node’s public signing key.
round_length: Option<TimeDiff>The next round length if this node is a validator.
next_upgrade: Option<NextUpgrade>Information about the next scheduled upgrade staged for this node.
build_version: StringThe compiled node version.
uptime: TimeDiffTime that passed since the node has started.
reactor_state: ReactorStateThe current state of node reactor.
last_progress: TimestampTimestamp of the last recorded progress in the reactor.
available_block_range: AvailableBlockRangeThe available block range in storage.
block_sync: BlockSynchronizerStatusThe status of the block synchronizer builders.