Various data types of the Casper network.
Structs
- Auction
State - The state associated with the auction system contract as at the given block height and corresponding state root hash.
- Deploy
Execution Info - The block hash and height in which a given deploy was executed, along with the execution result if known.
- Json
Block With Signatures - A JSON-friendly representation of a block and the signatures for that block.
- Legacy
Execution Result - The execution result of a single deploy.