Module types

Various data types of the Casper network.

Re-exports

pub use auction_state::AuctionState;

Modules

auction_state
Types associated with reporting auction state.

Structs

Account
Structure representing a user’s account, stored in global state.
ActionThresholds
Thresholds that have to be met when executing an action of a certain type.
Approval
The signature of a deploy and the public key of the signer.
AssociatedKey
A representation of a public key and weight which can be associated with a given Account or Contract.
Block
A block; the core component of the Casper linear blockchain.
BlockBody
The body portion of a block.
BlockHash
A cryptographic hash uniquely identifying a Block.
BlockHashAndHeight
Describes a block’s hash and height.
BlockHeader
The header portion of a Block.
Contract
Details of a smart contract.
ContractPackage
Contract definition, metadata, and security container.
Deploy
A signed item sent to the network used to request execution of Wasm.
DeployBuilder
A builder for constructing a Deploy.
DeployHash
A cryptographic hash uniquely identifying a Deploy.
DeployHeader
The header portion of a Deploy.
EraEnd
Information included in switch blocks about the era the block concludes and the subsequent era.
EraReport
Equivocation and reward information included in switch blocks.
ExecutionResult
The execution result of a single deploy.
NamedKey
A named key. An Account or Contract may store a collection of named keys in global state.
Proof
A pair of public key and signature, representing proof of having signed a given piece of data, generally a Block.
Reward
A reward to be given to the specified validator.
TimeDiff
A time difference between two timestamps.
Timestamp
A timestamp newtype, representing a specific moment in time.
ValidatorWeight
The amount of weight a given validator has.

Enums

ExecutableDeployItem
The payment or session code of a Deploy.
StoredValue
A value stored in global state.

Constants

MAX_SERIALIZED_SIZE_OF_DEPLOY
The maximum permissible size in bytes of a Deploy when serialized via ToBytes.

Functions

validate_block_hashes_v1
Cryptographically validates the hashes of the given block, using the initial version of hashing.
validate_block_hashes_v2
Cryptographically validates the hashes of the given block, using the second version of hashing.