Various data types of the Casper network.
Re-exports
pub use auction_state::AuctionState;
Modules
- auction_
state - Types associated with reporting auction state.
Structs
- Account
- Structure representing a user’s account, stored in global state.
- Action
Thresholds - Thresholds that have to be met when executing an action of a certain type.
- Approval
- The signature of a deploy and the public key of the signer.
- Associated
Key - A representation of a public key and weight which can be associated with a given
AccountorContract. - Block
- A block; the core component of the Casper linear blockchain.
- Block
Body - The body portion of a block.
- Block
Hash - A cryptographic hash uniquely identifying a
Block. - Block
Hash AndHeight - Describes a block’s hash and height.
- Block
Header - The header portion of a
Block. - Contract
- Details of a smart contract.
- Contract
Package - Contract definition, metadata, and security container.
- Deploy
- A signed item sent to the network used to request execution of Wasm.
- Deploy
Builder - A builder for constructing a
Deploy. - Deploy
Hash - A cryptographic hash uniquely identifying a
Deploy. - Deploy
Header - The header portion of a
Deploy. - EraEnd
- Information included in switch blocks about the era the block concludes and the subsequent era.
- EraReport
- Equivocation and reward information included in switch blocks.
- Execution
Result - The execution result of a single deploy.
- Named
Key - A named key. An
AccountorContractmay store a collection of named keys in global state. - Proof
- A pair of public key and signature, representing proof of having signed a given piece of data,
generally a
Block. - Reward
- A reward to be given to the specified validator.
- Time
Diff - A time difference between two timestamps.
- Timestamp
- A timestamp newtype, representing a specific moment in time.
- Validator
Weight - The amount of weight a given validator has.
Enums
- Executable
Deploy Item - The payment or session code of a
Deploy. - Stored
Value - A value stored in global state.
Constants
- MAX_
SERIALIZED_ SIZE_ OF_ DEPLOY - The maximum permissible size in bytes of a Deploy when serialized via
ToBytes.
Functions
- validate_
block_ hashes_ v1 - Cryptographically validates the hashes of the given block, using the initial version of hashing.
- validate_
block_ hashes_ v2 - Cryptographically validates the hashes of the given block, using the second version of hashing.