pub struct AssociatedKey { /* private fields */ }Expand description
A representation of a public key and weight which can be associated with a given Account or
Contract.
Note, the “key” in this case is represented by an AccountHash.
Implementations
Sourceimpl AssociatedKey
impl AssociatedKey
Sourcepub fn account_hash(&self) -> &AccountHash
pub fn account_hash(&self) -> &AccountHash
Returns the account hash of this associated key.